@@ -134,7 +134,7 @@ class CfnProfilingGroup(
                 *,
                 profiling_group_name: builtins.str,
                 agent_permissions: typing.Any = None,
-                anomaly_detection_notification_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, typing.Union["CfnProfilingGroup.ChannelProperty", typing.Dict[str, typing.Any]]]]]] = None,
+                anomaly_detection_notification_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, typing.Union[CfnProfilingGroup.ChannelProperty, typing.Dict[str, typing.Any]]]]]] = None,
                 compute_platform: typing.Optional[builtins.str] = None,
                 tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.core.CfnTag, typing.Dict[str, typing.Any]]]] = None,
             ) -> None:
@@ -269,7 +269,7 @@ class CfnProfilingGroup(
     ) -> None:
         if __debug__:
             def stub(
-                value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnProfilingGroup.ChannelProperty"]]]],
+                value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnProfilingGroup.ChannelProperty]]]],
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
